@@ -19,6 +19,9 @@
 // TQScintilla; see the file LICENSE.  If not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -816,7 +819,7 @@ ColourDesired Platform::ChromeHighlight()
 
 const char *Platform::DefaultFont()
 {
-	return TQApplication::font().family();
+	return TQApplication::font().family().utf8();
 }
 
 int Platform::DefaultFontSize()
