@@ -21,6 +21,9 @@
 // TQScintilla; see the file LICENSE.  If not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
 #include <string.h>
 #include <tqapplication.h>
@@ -3029,3 +3032,5 @@ void QextScintilla::handleUserListSelection(const char *text, int id)
 {
     emit userListActivated(id, TQString(text));
 }
+
+#include "qextscintilla.moc"
